@@ -1,4 +1,4 @@
-#"""Container for metadata of individual simulations"""
+"""Container for metadata of individual simulations"""
 
 import re
 import collections
@@ -270,7 +270,7 @@ class Metadata(collections.OrderedDict):
         """Write to JSON file"""
         from pathlib import Path
         path = Path(json_file).expanduser().resolve().with_suffix(".json")
-        path.mkdir(parents=True, exist_ok=True)
+        path.parent.mkdir(parents=True, exist_ok=True)
         with path.open("w") as f:
             f.write(self.to_json(indent=indent, separators=separators))
 
@@ -524,10 +524,10 @@ class Metadata(collections.OrderedDict):
             new[key] = self[key]
         return new
 
-    @classmethod
-    def fromkeys(cls, iterable):
-        iterable = [(_valid_identifier(k), v) for k, v in iterable]
-        return super(Metadata, cls).fromkeys(iterable)
+    # @classmethod
+    # def fromkeys(cls, iterable):
+    #     iterable = [(_valid_identifier(k), v) for k, v in iterable]
+    #     return super(Metadata, cls).fromkeys(iterable)
 
     @property
     def resolution(self):
