@@ -9,11 +9,6 @@ class WaveformMixin(abc.ABC):
     # Note: This is currently a pretty trivial class, but as the code develops
     # this will be increasingly useful.
 
-    @property
-    @abc.abstractmethod
-    def t(self):  # Handy alias for backwards compatibility
-        return self.time
-
     @property
     @abc.abstractmethod
     def data(self):  # Handy alias for backwards compatibility
